@@ -1,10 +1,11 @@
 # -*- coding: utf-8 -*-
-# (c) 2020 Andreas Motl <andreas@hiveeyes.org>
+# (c) 2020-2021 Andreas Motl <andreas@hiveeyes.org>
+# License: GNU Affero General Public License, Version 3
 import io
 from contextlib import redirect_stdout
+from datetime import datetime
 
 import tabulate
-from datetime import datetime
 from dateparser import parse as parsedate
 
 
@@ -17,30 +18,28 @@ class Formatter:
     """
 
     LABEL_MAP = {
-        'Datum': 'date',
-
-        'morgens': 'morning',
-        'mittags': 'noon',
-        'abends': 'evening',
-
-        'kein': 'no',
-        'gering': 'low',
-        'mittel': 'medium',
-        'stark': 'strong',
-        'intensiv': 'intensive',
+        "Datum": "date",
+        "morgens": "morning",
+        "mittags": "noon",
+        "abends": "evening",
+        "kein": "no",
+        "gering": "low",
+        "mittel": "medium",
+        "stark": "strong",
+        "intensiv": "intensive",
     }
 
     STRENGTH_MACHINE_MAP = {
-        'no': 0,
-        'low': 1,
-        'medium': 2,
-        'strong': 3,
-        'intensive': 4,
+        "no": 0,
+        "low": 1,
+        "medium": 2,
+        "strong": 3,
+        "intensive": 4,
     }
 
     def __init__(self, result):
         self.result = result
-        self.data = result["data"]
+        self.data = result.data
 
     def translate(self):
         for item in self.data:
@@ -62,9 +61,9 @@ class Formatter:
         data = self.normalize()
         for item in data:
             for key, value in item.items():
-                if key == 'date':
+                if key == "date":
                     value += str(datetime.now().year)
-                    value = parsedate(value).strftime('%Y-%m-%d')
+                    value = parsedate(value).strftime("%Y-%m-%d")
                 elif value in self.STRENGTH_MACHINE_MAP.keys():
                     value = self.STRENGTH_MACHINE_MAP[value]
                 item[key] = value
@@ -74,10 +73,19 @@ class Formatter:
         with io.StringIO() as buffer, redirect_stdout(buffer):
 
             # Report about weather station / observation location
-            print(u'### Prognose des Bienenfluges in {}'.format(self.result['station']))
+            print(
+                u"### Prognose des Bienenfluges in {}".format(self.result.station_name)
+            )
             print()
 
             # Output forecast data
-            print(tabulate.tabulate(self.data[1:], headers=self.data[0], showindex=False, tablefmt='pipe'))
+            print(
+                tabulate.tabulate(
+                    self.data[1:],
+                    headers=self.data[0],
+                    showindex=False,
+                    tablefmt="pipe",
+                )
+            )
 
             return buffer.getvalue()
